@@ -11,6 +11,7 @@ from colorama import init
 from pathlib import Path
 
 targetPaths = []
+workTree = []
 stats = []
 cont = ''
 greenFlag = False
@@ -170,10 +171,10 @@ def PrLightPurple(skk):
 #--------------------------------
 
 @click.group()
-@click.pass_context
 def root():
     """Traslation of DocFX source code"""
     init()
+    global workTree
     if sourceDir.split('/')[0] not in os.listdir():
         PrRed('\nPath "' + sourceDir.split('/')[0] + '" has not been found!')
         exit()
@@ -198,135 +199,134 @@ def root():
 
     # option = input(' Digite uma opção:\n [1] para traduzir arquivos modificados desde o último commit,\n [2] para traduzir todo o projeto, ou\n [Enter] para sair: ')
 
-    @root.command('diff')
-    @click.pass_context
-    def diff(workTree):
-        if workTree:
-            PrYellow('\n The following files will be added or overwritten in target languages:')
+@root.command()
+def diff():
+    if workTree:
+        PrYellow('\n The following files will be added or overwritten in target languages:')
+        for doc in workTree:
+            if doc.split('/')[-1] in os.listdir(sourceDir + '/' + '/'.join(doc.split('/')[1:-1])):
+                stats.append(FileStats(sourceDir.split('/')[0] + '/' + doc))
+                PrLightPurple(sourceDir.split('/')[0] + '/' + doc)
+            else:
+                PrYellow(sourceDir.split('/')[0] + '/' + doc + ' will be deleted in target languages.')
+        fls = list(filter(lambda x: x is not None, stats))
+        for i in range(len(fls)):
+            reqs += fls[i][0]
+            chars += fls[i][1]
+        estimatedT = int(reqs*.7)
+        print('\n Target languages:\t\t\t' + ', '.join(targetLangs))
+        print(' Total of calls to be made to the machine translation service:\t' + str(reqs))
+        print(' Total of characters to be sent to the machine translation service:\t' + str(chars))
+        print(' Estimated process duration:\t\t' + str(datetime.timedelta(seconds = estimatedT)))
+        cont = input('\n Continue [c] or abort [Enter]? ')
+        if cont == 'c':
             for doc in workTree:
                 if doc.split('/')[-1] in os.listdir(sourceDir + '/' + '/'.join(doc.split('/')[1:-1])):
-                    stats.append(FileStats(sourceDir.split('/')[0] + '/' + doc))
-                    PrLightPurple(sourceDir.split('/')[0] + '/' + doc)
+                    ProcessFiles(sourceDir.split('/')[0] + '/' + doc)
                 else:
-                    PrYellow(sourceDir.split('/')[0] + '/' + doc + ' will be deleted in target languages.')
+                    for path in targetPaths:
+                        try:
+                            os.remove(path + '/' + '/'.join(doc.split('/')[2:]))
+                        except:
+                            pass
+            PrGreen('\n\n Completed successfully!')
+    else:
+        PrYellow('There are no changes since the last commit.')
+    if cont != 'c': PrRed('\n\n Exiting...')
+    time.sleep(1)
+
+@root.command()
+def all():
+    global processed
+    global greenFlag
+    while not processed:
+        if greenFlag:
+            for item in Path(sourceDir.split('/')[0]).iterdir():
+                if item.name != sourceDir.split('/')[1] and item.name in list(map(lambda x: '_'.join(x.split('-')).lower(), targetLangs)) and item.is_dir():
+                    shutil.rmtree(sourceDir.split('/')[0] + '/' + item.name)
+            processed = True
+
+        if greenFlag:
+            for path in targetPaths:
+                os.mkdir(path)
+        for entry in Path(sourceDir).iterdir():
+            if entry.is_dir():
+                dirLevel2 = sourceDir + '/' + entry.name
+                if greenFlag:
+                    for path in targetPaths:
+                        os.mkdir(path + '/' + entry.name)
+                for entry2 in Path(dirLevel2).iterdir():
+                    if entry2.is_dir():
+                        tgSeg = '/' + entry.name + '/' + entry2.name
+                        dirLevel3 = dirLevel2 + '/' + entry2.name
+                        if greenFlag:
+                            for path in targetPaths:
+                                os.mkdir(path + tgSeg)
+                        for entry3 in Path(dirLevel3).iterdir():
+                            if entry3.is_dir():
+                                tgSeg = '/' + entry.name + '/' + entry2.name + '/' + entry3.name
+                                dirLevel4 = dirLevel3 + '/' + entry3.name
+                                if greenFlag:
+                                    for path in targetPaths:
+                                        os.mkdir(path + tgSeg)
+                                for entry4 in Path(dirLevel4).iterdir():
+                                    if entry4.is_dir():
+                                        tgSeg = '/' + entry.name + '/' + entry2.name + '/' + entry3.name + '/' + entry4.name
+                                        dirLevel5 = dirLevel4 + '/' + entry4.name
+                                        if greenFlag:
+                                            for path in targetPaths:
+                                                os.mkdir(path + tgSeg)
+                                        for entry5 in Path(dirLevel5).iterdir():
+                                            if not entry5.is_dir():
+                                                if greenFlag:
+                                                    ProcessFiles(dirLevel5 + '/' + entry5.name)
+                                                else:
+                                                    stats.append(FileStats(dirLevel5 + '/' + entry5.name))
+                                    else:
+                                        if greenFlag:
+                                            ProcessFiles(dirLevel4 + '/' + entry4.name)
+                                        else:
+                                            stats.append(FileStats(dirLevel4 + '/' + entry4.name))
+                            else:
+                                if greenFlag:
+                                    ProcessFiles(dirLevel3 + '/' + entry3.name)
+                                else:
+                                    stats.append(FileStats(dirLevel3 + '/' + entry3.name))
+                    else:
+                        if greenFlag:
+                            ProcessFiles(dirLevel2 + '/' + entry2.name)
+                        else:
+                            stats.append(FileStats(dirLevel2 + '/' + entry2.name))
+            else:
+                if greenFlag:
+                    ProcessFiles(sourceDir + '/' + entry.name)
+                else:
+                    stats.append(FileStats(sourceDir + '/' + entry.name))
+        
+        if not greenFlag:
             fls = list(filter(lambda x: x is not None, stats))
+            nFls = len(fls)*len(targetLangs)
+            print('\n Target languages:\t\t\t' + ', '.join(targetLangs))
+            print(' Total of source language files:\t' + str(len(fls)))
             for i in range(len(fls)):
                 reqs += fls[i][0]
                 chars += fls[i][1]
             estimatedT = int(reqs*.7)
-            print('\n Target languages:\t\t\t' + ', '.join(targetLangs))
+            print(' Total of source language characters:\t' + str(chars))
+            print(' Total of target language files to be generated:\t' + str(nFls))
             print(' Total of calls to be made to the machine translation service:\t' + str(reqs))
             print(' Total of characters to be sent to the machine translation service:\t' + str(chars))
             print(' Estimated process duration:\t\t' + str(datetime.timedelta(seconds = estimatedT)))
             cont = input('\n Continue [c] or abort [Enter]? ')
             if cont == 'c':
-                for doc in workTree:
-                    if doc.split('/')[-1] in os.listdir(sourceDir + '/' + '/'.join(doc.split('/')[1:-1])):
-                        ProcessFiles(sourceDir.split('/')[0] + '/' + doc)
-                    else:
-                        for path in targetPaths:
-                            try:
-                                os.remove(path + '/' + '/'.join(doc.split('/')[2:]))
-                            except:
-                                pass
-                PrGreen('\n\n Completed successfully!')
-        else:
-            PrYellow('There are no changes since the last commit.')
-        if cont != 'c': PrRed('\n\n Exiting...')
-        time.sleep(1)
+                greenFlag = True
+            else:
+                break
 
-    @root.command('all')
-    def all():
-        global processed
-        global greenFlag
-        while not processed:
-            if greenFlag:
-                for item in Path(sourceDir.split('/')[0]).iterdir():
-                    if item.name != sourceDir.split('/')[1] and item.name in list(map(lambda x: '_'.join(x.split('-')).lower(), targetLangs)) and item.is_dir():
-                        shutil.rmtree(sourceDir.split('/')[0] + '/' + item.name)
-                processed = True
+    if greenFlag:
+        PrGreen('\n\n Completed successfully!')
+    else:
+        PrRed('\n\n Exiting...')
+    time.sleep(1)
 
-            if greenFlag:
-                for path in targetPaths:
-                    os.mkdir(path)
-            for entry in Path(sourceDir).iterdir():
-                if entry.is_dir():
-                    dirLevel2 = sourceDir + '/' + entry.name
-                    if greenFlag:
-                        for path in targetPaths:
-                            os.mkdir(path + '/' + entry.name)
-                    for entry2 in Path(dirLevel2).iterdir():
-                        if entry2.is_dir():
-                            tgSeg = '/' + entry.name + '/' + entry2.name
-                            dirLevel3 = dirLevel2 + '/' + entry2.name
-                            if greenFlag:
-                                for path in targetPaths:
-                                    os.mkdir(path + tgSeg)
-                            for entry3 in Path(dirLevel3).iterdir():
-                                if entry3.is_dir():
-                                    tgSeg = '/' + entry.name + '/' + entry2.name + '/' + entry3.name
-                                    dirLevel4 = dirLevel3 + '/' + entry3.name
-                                    if greenFlag:
-                                        for path in targetPaths:
-                                            os.mkdir(path + tgSeg)
-                                    for entry4 in Path(dirLevel4).iterdir():
-                                        if entry4.is_dir():
-                                            tgSeg = '/' + entry.name + '/' + entry2.name + '/' + entry3.name + '/' + entry4.name
-                                            dirLevel5 = dirLevel4 + '/' + entry4.name
-                                            if greenFlag:
-                                                for path in targetPaths:
-                                                    os.mkdir(path + tgSeg)
-                                            for entry5 in Path(dirLevel5).iterdir():
-                                                if not entry5.is_dir():
-                                                    if greenFlag:
-                                                        ProcessFiles(dirLevel5 + '/' + entry5.name)
-                                                    else:
-                                                        stats.append(FileStats(dirLevel5 + '/' + entry5.name))
-                                        else:
-                                            if greenFlag:
-                                                ProcessFiles(dirLevel4 + '/' + entry4.name)
-                                            else:
-                                                stats.append(FileStats(dirLevel4 + '/' + entry4.name))
-                                else:
-                                    if greenFlag:
-                                        ProcessFiles(dirLevel3 + '/' + entry3.name)
-                                    else:
-                                        stats.append(FileStats(dirLevel3 + '/' + entry3.name))
-                        else:
-                            if greenFlag:
-                                ProcessFiles(dirLevel2 + '/' + entry2.name)
-                            else:
-                                stats.append(FileStats(dirLevel2 + '/' + entry2.name))
-                else:
-                    if greenFlag:
-                        ProcessFiles(sourceDir + '/' + entry.name)
-                    else:
-                        stats.append(FileStats(sourceDir + '/' + entry.name))
-            
-            if not greenFlag:
-                fls = list(filter(lambda x: x is not None, stats))
-                nFls = len(fls)*len(targetLangs)
-                print('\n Target languages:\t\t\t' + ', '.join(targetLangs))
-                print(' Total of source language files:\t' + str(len(fls)))
-                for i in range(len(fls)):
-                    reqs += fls[i][0]
-                    chars += fls[i][1]
-                estimatedT = int(reqs*.7)
-                print(' Total of source language characters:\t' + str(chars))
-                print(' Total of target language files to be generated:\t' + str(nFls))
-                print(' Total of calls to be made to the machine translation service:\t' + str(reqs))
-                print(' Total of characters to be sent to the machine translation service:\t' + str(chars))
-                print(' Estimated process duration:\t\t' + str(datetime.timedelta(seconds = estimatedT)))
-                cont = input('\n Continue [c] or abort [Enter]? ')
-                if cont == 'c':
-                    greenFlag = True
-                else:
-                    break
-
-        if greenFlag:
-            PrGreen('\n\n Completed successfully!')
-        else:
-            PrRed('\n\n Exiting...')
-        time.sleep(1)
-
-    re.purge()
+re.purge()
